==> apache-seata-2.3.0-incubating-src.tar.gz: apache-seata-2.3.0-incubating-src/compatible/src/test/java/io/seata/spi/SPITest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.seata.spi;

import java.util.List;
import java.util.stream.Collectors;

import org.apache.seata.common.loader.EnhancedServiceLoader;
import org.apache.seata.core.model.BranchType;
import org.apache.seata.core.model.ResourceManager;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

public class SPITest {

    @Test
    public void testRmSPIOrder() {
        EnhancedServiceLoader.unload(ResourceManager.class);
        List<ResourceManager> resourceManagers = EnhancedServiceLoader.loadAll(ResourceManager.class);
        List<ResourceManager> list = resourceManagers.stream().filter(resourceManager -> resourceManager.getBranchType().equals(BranchType.SAGA)).collect(Collectors.toList());
        Assertions.assertNotNull(list);
        ResourceManager resourceManager = list.get(list.size() - 1);
        Assertions.assertEquals("io.seata.saga.rm.SagaResourceManager", resourceManager.getClass().getName());
    }
}

==> apache-seata-2.5.0-incubating-src.tar.gz: apache-seata-2.5.0-incubating-src/compatible/src/test/java/io/seata/spi/SPITest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.seata.spi;

import org.apache.seata.common.loader.EnhancedServiceLoader;
import org.apache.seata.core.model.BranchType;
import org.apache.seata.core.model.ResourceManager;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import java.util.List;
import java.util.stream.Collectors;

public class SPITest {

    @Test
    public void testRmSPIOrder() {
        EnhancedServiceLoader.unload(ResourceManager.class);
        List<ResourceManager> resourceManagers = EnhancedServiceLoader.loadAll(ResourceManager.class);
        List<ResourceManager> list = resourceManagers.stream()
                .filter(resourceManager -> resourceManager.getBranchType().equals(BranchType.SAGA))
                .collect(Collectors.toList());
        Assertions.assertNotNull(list);
        ResourceManager resourceManager = list.get(list.size() - 1);
        Assertions.assertEquals(
                "io.seata.saga.rm.SagaResourceManager",
                resourceManager.getClass().getName());
    }
}
